@@ -16,7 +16,7 @@ Usage::
     session_client: ImagebuilderClient = session.client("imagebuilder")
     ```
 """
-from mypy_boto3_imagebuilder.client import ImagebuilderClient
+from .client import ImagebuilderClient
 
 Client = ImagebuilderClient
 
